==> grass_6.0.0.orig.tar.gz: grass-6.0.0/raster/r.terraflow/grid.h <==
/*C
 * Original project: Lars Arge, Jeff Chase, Pat Halpin, Laura Toma, Dean
 *		     Urban, Jeff Vitter, Rajiv Wickremesinghe 1999
 * 
 * GRASS Implementation: Lars Arge, Helena Mitasova, Laura Toma 2002
 *
 * Copyright (c) 2002 Duke University -- Laura Toma 
 *
 * Copyright (c) 1999-2001 Duke University --
 * Laura Toma and Rajiv Wickremesinghe
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Duke University
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE TRUSTEES AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE TRUSTEES OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *C*/



#ifndef GRID_H
#define GRID_H

#include <ami.h>
#include "types.h"
#include "plateau.h"
#include "water.h"

/* define to keep i,j values (used in printing) */
/* #define KEEP_COORDS */


struct gridElement {
  direction_type dir;
  char valid;			 /* whether part of plateau in grid */
  bfs_depth_type depth;
#ifdef KEEP_COORDS
  dimension_type i,j;
#endif
};



class grid {
private:
  gridElement *data;
  dimension_type iMin, jMin;
  dimension_type width, height;
  cclabel_type label;
  long size;
  queue<gridElement *> boundaryQueue[2];
public:
  grid(dimension_type iMin, dimension_type jMin,
	   dimension_type iMax, dimension_type jMax,
	   long size,
	   cclabel_type label);
  ~grid();
  void load(AMI_STREAM<plateauType> &str);
  void save(AMI_STREAM<waterType> &str);
  void print();
  void assignDirections(int sfdmode); /* single flow directions */
  gridElement *grid::getNeighbour(gridElement *datap, int k);
  direction_type getDirection(int);
};


#endif

==> grass_6.2.3.orig.tar.gz: grass-6.2.3/raster/r.terraflow/grid.h <==
/*C
 * Original project: Lars Arge, Jeff Chase, Pat Halpin, Laura Toma, Dean
 *		     Urban, Jeff Vitter, Rajiv Wickremesinghe 1999
 * 
 * GRASS Implementation: Lars Arge, Helena Mitasova, Laura Toma 2002
 *
 * Copyright (c) 2002 Duke University -- Laura Toma 
 *
 * Copyright (c) 1999-2001 Duke University --
 * Laura Toma and Rajiv Wickremesinghe
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by Duke University
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE TRUSTEES AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE TRUSTEES OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *C*/



#ifndef GRID_H
#define GRID_H

#include <ami.h>
#include "types.h"
#include "plateau.h"
#include "water.h"

/* define to keep i,j values (used in printing) */
/* #define KEEP_COORDS */


struct gridElement {
  direction_type dir;
  char valid;			 /* whether part of plateau in grid */
  bfs_depth_type depth;
#ifdef KEEP_COORDS
  dimension_type i,j;
#endif
};



class grid {
private:
  gridElement *data;
  dimension_type iMin, jMin;
  dimension_type width, height;
  cclabel_type label;
  long size;
  queue<gridElement *> boundaryQueue[2];
public:
  grid(dimension_type iMin, dimension_type jMin,
	   dimension_type iMax, dimension_type jMax,
	   long size,
	   cclabel_type label);
  ~grid();
  void load(AMI_STREAM<plateauType> &str);
  void save(AMI_STREAM<waterType> &str);
  void print();
  void assignDirections(int sfdmode); /* single flow directions */
  gridElement *getNeighbour(gridElement *datap, int k);
  direction_type getDirection(int);
};


#endif
